
{% for object in page_obj.object_list %}
    <tr class="list-item list-item-selectable"
        data-role="list-item"
        data-item-id="{{ object.id }}">

        <td style="width: 20%">{{ object.code }}</td>
        <td style="width: 60%">
            <a href="{{ object.get_absolute_url }}" target="_blank">
                {{ object.name }}
            </a>
        </td>
        <td style="width: 40%">{{ object.price }}</td>
    </tr>
{% endfor %}

